# App

- [How to install app](https://docs.decentranetwork.org/apps/embedded/how_to_install_app.html)
- [Creating the App](https://docs.decentranetwork.org/apps/embedded/creating_a_app.html)
- [Definition For App](https://docs.decentranetwork.org/apps/embedded/definition_for_app.html)
